@@ -41,7 +41,7 @@ def process_texi (texifilename, i_blurb, n_blurb, write_skeleton, output_file=No
 			g.write (i_blurb)
 			tutu = re.findall (r"""^(\*) +([^:
 			]+)::[^
-			]*?$|^@(include|menu|end menu|node|(?:unnumbered|appendix)(?:(?:sub){0,2}sec)?|top|chapter|(?:sub){0,2}section|(?:major|chap|(?:sub){0,2})heading) *([^@
+			]*?$|^@(include|menu|end menu|node|(?:unnumbered|appendix)(?:(?:sub){0,2}sec)?|top|chapter|(?:sub){0,2}section|(?:major|chap|(?:sub){0,2})heading) *([^
 			]*)[^
 			]*?$""", texifile, re.M)
 			node_trigger = False
@@ -61,7 +61,7 @@ def process_texi (texifilename, i_blurb, n_blurb, write_skeleton, output_file=No
 						includes.append(item[3])
 			g.close ()
 		elif output_file:
-			toto = re.findall (r"""^@(include|node|(?:unnumbered|appendix)(?:(?:sub){0,2}sec)?|top|chapter|(?:sub){0,2}section|(?:major|chap|(?:sub){0,2})heading) *([^@
+			toto = re.findall (r"""^@(include|node|(?:unnumbered|appendix)(?:(?:sub){0,2}sec)?|top|chapter|(?:sub){0,2}section|(?:major|chap|(?:sub){0,2})heading) *([^
 			]*)[^
 			]*?$""", texifile, re.M)
 			for item in toto:
